@@ -134,7 +134,7 @@ LOG = logging.getLogger(__name__)
 
 __all__ = ["process_request", "wsgi_application", "start_standalone_server",
            "Client"]
-__version__ = "0.2"
+__version__ = "0.2.1"
 
 
 class BaseError(Exception):
@@ -248,7 +248,7 @@ def rpc_method(function):
     _register_rpc_method(function)
 
     def wrapper(*args, **kwargs):
-        function(*args, **kwargs)
+        return function(*args, **kwargs)
 
     return wrapper
 
